# eric7.EricWidgets.EricSimpleHelpDialog

Module implementing a dialog to show some help text.

### Global Attributes

None

### Classes

EricSimpleHelpDialog | Class implementing a dialog to show some help text.

### Functions

None

## EricSimpleHelpDialog

Class implementing a dialog to show some help text.

### Derived from

QDialog, Ui_EricSimpleHelpDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricSimpleHelpDialog | Constructor

### Static Methods

None

#### EricSimpleHelpDialog (Constructor)

EricSimpleHelpDialog(title="", label="", helpStr="", parent=None)

Constructor

title (str)
  title of the window
label (str)
  label for the help
helpStr (str)
  HTML help text
parent (QWidget)
  reference to the parent widget

Up